==> dev-plugin-android-6.1.9-beta1-sources.jar: com/zoyi/channel/plugin/android/push/NotificationFactory.java <==
package com.zoyi.channel.plugin.android.push;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.graphics.BitmapFactory;
import android.os.Build;
import android.os.Build.VERSION_CODES;
import android.support.annotation.Nullable;
import android.support.v4.app.NotificationCompat;
import android.text.TextUtils;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.global.Const;

public class NotificationFactory {

  @Nullable
  static NotificationCompat.Builder createPushMessage(Context context, PushData pushData) {
    NotificationCompat.Builder builder = createBuilder(context, pushData);

    if (builder == null) {
      return null;
    }
    return builder;
  }

  @Nullable
  private static NotificationCompat.Builder createBuilder(Context context, PushData pushData) {
    String message = pushData.getMessage();

    if (TextUtils.isEmpty(message)) {
      return null;
    } else {
      NotificationCompat.Builder builder = initBuilder(context);
      builder
          .setSmallIcon(R.drawable.ch_push_icon)
          .setLargeIcon(BitmapFactory.decodeResource(context.getResources(), R.drawable.ch_push_large_icon))
          .setContentTitle(context.getString(R.string.notification_title))
          .setContentText(message)
          .setContentIntent(getContentIntent(context, pushData))
          .setAutoCancel(true)
          .setStyle(getBigTextStyle(message))
          .setDefaults(Notification.DEFAULT_ALL);

      if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
        builder.setCategory(Notification.CATEGORY_MESSAGE)
            .setPriority(Notification.PRIORITY_HIGH)
            .setVisibility(Notification.VISIBILITY_PUBLIC);
      }
      return builder;
    }
  }

  private static NotificationCompat.Builder initBuilder(Context context) {
    if (Build.VERSION.SDK_INT >= VERSION_CODES.O && isOreoSupportLibrary()) {
      NotificationManager notificationManager = (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);
      if (notificationManager != null) {
        NotificationChannel channel = new NotificationChannel(
            "ChannelIO",
            "ChannelIO",
            NotificationManager.IMPORTANCE_HIGH);
        notificationManager.createNotificationChannel(channel);
        return new NotificationCompat.Builder(context, channel.getId());
      }
    }

    return new NotificationCompat.Builder(context);
  }

  private static boolean isOreoSupportLibrary() {
    try {
      NotificationCompat.Builder.class.getConstructor(Context.class, String.class);
      return true;
    } catch (NoSuchMethodException e) {
      return false;
    }
  }

  private static PendingIntent getContentIntent(Context context, PushData pushData) {
    Intent clickIntent = new Intent(ChannelBroadcastReceiver.ACTION_CHANNEL_PLUGIN_PUSH_CLICK);
    clickIntent.setComponent(new ComponentName(context, ChannelBroadcastReceiver.class));
    clickIntent.putExtra(Const.EXTRA_HOST_APP_INTENT, getHostAppIntent(context, pushData));

    return PendingIntent.getBroadcast(
        context,
        Const.REQUEST_PUSH_MESSAGE,
        clickIntent,
        PendingIntent.FLAG_UPDATE_CURRENT);
  }

  private static Intent getHostAppIntent(Context context, PushData pushData) {
    Intent hostAppIntent = context.getPackageManager().getLaunchIntentForPackage(context.getPackageName());

    if (hostAppIntent == null) {
      hostAppIntent = new Intent();
    } else {
      hostAppIntent.addCategory(Intent.CATEGORY_LAUNCHER);
      hostAppIntent.putExtra(Const.EXTRA_CHAT_ID, pushData.getChatId());
    }

    hostAppIntent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK | Intent.FLAG_ACTIVITY_NEW_TASK);

    return hostAppIntent;
  }

  private static NotificationCompat.BigTextStyle getBigTextStyle(String message) {
    return new NotificationCompat.BigTextStyle()
        .bigText(message);
  }

}

==> dev-plugin-android-9.0.0+beta1-sources.jar: com/zoyi/channel/plugin/android/push/NotificationFactory.java <==
package com.zoyi.channel.plugin.android.push;

import android.app.*;
import android.content.*;
import android.content.pm.ApplicationInfo;
import android.graphics.BitmapFactory;
import android.os.Build;
import android.os.Build.VERSION_CODES;
import androidx.annotation.Nullable;
import androidx.core.app.NotificationCompat;
import android.text.TextUtils;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.global.Const;

public class NotificationFactory {

  @Nullable
  static NotificationCompat.Builder createPushMessage(Context context, PushData pushData) {
    NotificationCompat.Builder builder = createBuilder(context, pushData);

    if (builder == null) {
      return null;
    }
    return builder;
  }

  private static String getNotificationTitle(Context context) {
    String title = context.getString(R.string.notification_title);

    if (!TextUtils.isEmpty(title)) {
      return title;
    }

    ApplicationInfo applicationInfo = context.getApplicationInfo();
    int stringId = applicationInfo.labelRes;

    return stringId == 0 ? context.getString(R.string.notification_default_title) : context.getString(stringId);
  }

  @Nullable
  private static NotificationCompat.Builder createBuilder(Context context, PushData pushData) {
    String message = pushData.getMessage();

    if (TextUtils.isEmpty(message)) {
      return null;
    } else {
      NotificationCompat.Builder builder = initBuilder(context);
      builder
          .setSmallIcon(R.drawable.ch_push_icon)
          .setLargeIcon(BitmapFactory.decodeResource(context.getResources(), R.drawable.ch_push_large_icon))
          .setContentTitle(getNotificationTitle(context))
          .setContentText(message)
          .setContentIntent(getContentIntent(context, pushData))
          .setAutoCancel(true)
          .setStyle(getBigTextStyle(message))
          .setDefaults(Notification.DEFAULT_ALL);

      if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
        builder.setCategory(Notification.CATEGORY_MESSAGE)
            .setPriority(Notification.PRIORITY_HIGH)
            .setVisibility(Notification.VISIBILITY_PUBLIC);
      }
      return builder;
    }
  }

  private static NotificationCompat.Builder initBuilder(Context context) {
    if (Build.VERSION.SDK_INT >= VERSION_CODES.O && isOreoSupportLibrary()) {
      NotificationManager notificationManager = (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);
      if (notificationManager != null) {
        NotificationChannel channel = new NotificationChannel(
            "ChannelIO",
            "ChannelIO",
            NotificationManager.IMPORTANCE_HIGH);
        notificationManager.createNotificationChannel(channel);
        return new NotificationCompat.Builder(context, channel.getId());
      }
    }

    return new NotificationCompat.Builder(context);
  }

  private static boolean isOreoSupportLibrary() {
    try {
      NotificationCompat.Builder.class.getConstructor(Context.class, String.class);
      return true;
    } catch (NoSuchMethodException e) {
      return false;
    }
  }

  private static PendingIntent getContentIntent(Context context, PushData pushData) {
    Intent clickIntent = new Intent(ChannelBroadcastReceiver.ACTION_CHANNEL_PLUGIN_PUSH_CLICK);
    clickIntent.setComponent(new ComponentName(context, ChannelBroadcastReceiver.class));
    clickIntent.putExtra(Const.EXTRA_HOST_APP_INTENT, getHostAppIntent(context, pushData));

    return PendingIntent.getBroadcast(
        context,
        Const.REQUEST_PUSH_MESSAGE,
        clickIntent,
        PendingIntent.FLAG_UPDATE_CURRENT);
  }

  private static Intent getHostAppIntent(Context context, PushData pushData) {
    Intent hostAppIntent = context.getPackageManager().getLaunchIntentForPackage(context.getPackageName());

    if (hostAppIntent == null) {
      hostAppIntent = new Intent();
    } else {
      hostAppIntent.addCategory(Intent.CATEGORY_LAUNCHER);
      hostAppIntent.putExtra(Const.EXTRA_CHANNEL_ID, pushData.getChannelId());
      hostAppIntent.putExtra(Const.EXTRA_PERSON_TYPE, pushData.getPersonType());
      hostAppIntent.putExtra(Const.EXTRA_PERSON_ID, pushData.getPersonId());
      hostAppIntent.putExtra(Const.EXTRA_CHAT_ID, pushData.getChatId());
    }

    hostAppIntent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TASK | Intent.FLAG_ACTIVITY_NEW_TASK);

    return hostAppIntent;
  }

  private static NotificationCompat.BigTextStyle getBigTextStyle(String message) {
    return new NotificationCompat.BigTextStyle()
        .bigText(message);
  }

}
